@@ -22,7 +22,11 @@ from rich.table import Table
 from cyberfusion.ClusterApiCli import ClusterApiRequest
 from cyberfusion.ClusterSupport._interfaces import APIObjectInterface
 from cyberfusion.ClusterSupport.api_keys import ENDPOINT_API_KEYS, APIKey
-from cyberfusion.ClusterSupport.api_users import ENDPOINT_API_USERS, APIUser
+from cyberfusion.ClusterSupport.api_users import (
+    ENDPOINT_PUBLIC_API_USERS,
+    APIUser,
+    ENDPOINT_ADMIN_API_USERS,
+)
 from cyberfusion.ClusterSupport.api_users_to_clusters import (
     ENDPOINT_API_USERS_TO_CLUSTERS,
     APIUserToCluster,
@@ -57,7 +61,11 @@ from cyberfusion.ClusterSupport.cluster_ip_addresses_products import (
     ENDPOINT_CLUSTER_IP_ADDRESSES_PRODUCTS,
     ClusterIPAddressProduct,
 )
-from cyberfusion.ClusterSupport.clusters import ENDPOINT_CLUSTERS, Cluster
+from cyberfusion.ClusterSupport.clusters import (
+    ENDPOINT_PUBLIC_CLUSTERS,
+    Cluster,
+    ENDPOINT_INTERNAL_CLUSTERS,
+)
 from cyberfusion.ClusterSupport.clusters_cephfs_credentials import (
     ClusterCephFSCredentials,
 )
@@ -80,7 +88,7 @@ from cyberfusion.ClusterSupport.customer_ip_addresses_products import (
     ENDPOINT_CUSTOMER_IP_ADDRESSES_PRODUCTS,
     CustomerIPAddressProduct,
 )
-from cyberfusion.ClusterSupport.customers import ENDPOINT_CUSTOMERS, Customer
+from cyberfusion.ClusterSupport.customers import ENDPOINT_PUBLIC_CUSTOMERS, Customer
 from cyberfusion.ClusterSupport.daemons import (
     ENDPOINT_DAEMONS,
     MODEL_DAEMONS,
@@ -102,7 +110,7 @@ from cyberfusion.ClusterSupport.databases import (
     Database,
 )
 from cyberfusion.ClusterSupport.databases_usages import (
-    ENDPOINT_DATABASES_USAGES,
+    ENDPOINT_PUBLIC_DATABASES_USAGES,
     DatabaseUsage,
 )
 from cyberfusion.ClusterSupport.domain_routers import (
@@ -171,8 +179,9 @@ from cyberfusion.ClusterSupport.mail_accounts import (
     MailAccount,
 )
 from cyberfusion.ClusterSupport.mail_accounts_usages import (
-    ENDPOINT_MAIL_ACCOUNTS_USAGES,
+    ENDPOINT_PUBLIC_MAIL_ACCOUNTS_USAGES,
     MailAccountUsage,
+    ENDPOINT_INTERNAL_MAIL_ACCOUNTS_USAGES,
 )
 from cyberfusion.ClusterSupport.mail_aliases import (
     ENDPOINT_MAIL_ALIASES,
@@ -190,7 +199,7 @@ from cyberfusion.ClusterSupport.mail_hostnames import (
     MailHostname,
 )
 from cyberfusion.ClusterSupport.malwares import (
-    ENDPOINT_MALWARES,
+    ENDPOINT_PUBLIC_MALWARES,
     MODEL_MALWARES,
     Malware,
 )
@@ -208,7 +217,7 @@ from cyberfusion.ClusterSupport.node_add_ons_products import (
     ENDPOINT_NODE_ADD_ONS_PRODUCTS,
     NodeAddOnProduct,
 )
-from cyberfusion.ClusterSupport.nodes import ENDPOINT_NODES, MODEL_NODES, Node
+from cyberfusion.ClusterSupport.nodes import ENDPOINT_PUBLIC_NODES, MODEL_NODES, Node
 from cyberfusion.ClusterSupport.nodes_products import (
     ENDPOINT_NODES_PRODUCTS,
     NodeProduct,
@@ -249,7 +258,7 @@ from cyberfusion.ClusterSupport.service_accounts_to_customers import (
     ENDPOINT_SERVICE_ACCOUNTS_TO_CUSTOMERS,
     ServiceAccountToCustomer,
 )
-from cyberfusion.ClusterSupport.sites import ENDPOINT_SITES, Site
+from cyberfusion.ClusterSupport.sites import ENDPOINT_PUBLIC_SITES, Site
 from cyberfusion.ClusterSupport.sites_to_customers import (
     ENDPOINT_SITES_TO_CUSTOMERS,
     SiteToCustomer,
@@ -276,7 +285,7 @@ from cyberfusion.ClusterSupport.unix_users import (
     UNIXUser,
 )
 from cyberfusion.ClusterSupport.unix_users_home_directories_usages import (
-    ENDPOINT_UNIX_USERS_HOME_DIRECTORIES_USAGES,
+    ENDPOINT_PUBLIC_UNIX_USERS_HOME_DIRECTORIES_USAGES,
     UNIXUsersHomeDirectoryUsage,
 )
 from cyberfusion.ClusterSupport.unix_users_rabbitmq_credentials import (
@@ -285,7 +294,7 @@ from cyberfusion.ClusterSupport.unix_users_rabbitmq_credentials import (
     UNIXUserRabbitMQCredentials,
 )
 from cyberfusion.ClusterSupport.unix_users_usages import (
-    ENDPOINT_UNIX_USERS_USAGES,
+    ENDPOINT_PUBLIC_UNIX_USERS_USAGES,
     UNIXUserUsage,
 )
 from cyberfusion.ClusterSupport.url_redirects import (
@@ -302,10 +311,10 @@ from cyberfusion.Common import find_executable, get_hostname
 from cyberfusion.Common.Config import CyberfusionConfig
 
 ENDPOINTS_USAGES = [
-    ENDPOINT_MAIL_ACCOUNTS_USAGES,
-    ENDPOINT_UNIX_USERS_USAGES,
-    ENDPOINT_DATABASES_USAGES,
-    ENDPOINT_UNIX_USERS_HOME_DIRECTORIES_USAGES,
+    ENDPOINT_PUBLIC_MAIL_ACCOUNTS_USAGES,
+    ENDPOINT_PUBLIC_UNIX_USERS_USAGES,
+    ENDPOINT_PUBLIC_DATABASES_USAGES,
+    ENDPOINT_PUBLIC_UNIX_USERS_HOME_DIRECTORIES_USAGES,
 ]
 ENDPOINTS_LOGS = [ENDPOINT_ERROR_LOGS, ENDPOINT_ACCESS_LOGS]
 
@@ -376,7 +385,9 @@ class ClusterSupport:
         - Domain routers are loaded. The related certificate cannot be found, as
           it does not exist locally.
         """
-        self._clusters_children = self.get_data("api-users/clusters-children")
+        self._clusters_children = self.get_data(
+            ENDPOINT_PUBLIC_API_USERS + "/clusters-children"
+        )
 
     @cached_property
     def request(self) -> ClusterApiRequest:
@@ -396,12 +407,12 @@ class ClusterSupport:
     @cached_property
     def clusters(self) -> List[Cluster]:
         """Get object(s) from API."""
-        return self._get_objects(Cluster, ENDPOINT_CLUSTERS)
+        return self._get_objects(Cluster, ENDPOINT_PUBLIC_CLUSTERS)
 
     @cached_property
     def nodes(self) -> List[Node]:
         """Get object(s) from API."""
-        return self._get_objects(Node, ENDPOINT_NODES, MODEL_NODES)
+        return self._get_objects(Node, ENDPOINT_PUBLIC_NODES, MODEL_NODES)
 
     @cached_property
     def node_add_ons(self) -> List[Node]:
@@ -595,12 +606,12 @@ class ClusterSupport:
     @cached_property
     def sites(self) -> List[Site]:
         """Get object(s) from API."""
-        return self._get_objects(Site, ENDPOINT_SITES)
+        return self._get_objects(Site, ENDPOINT_PUBLIC_SITES)
 
     @cached_property
     def customers(self) -> List[Customer]:
         """Get object(s) from API."""
-        return self._get_objects(Customer, ENDPOINT_CUSTOMERS)
+        return self._get_objects(Customer, ENDPOINT_PUBLIC_CUSTOMERS)
 
     @cached_property
     def custom_config_snippets(self) -> List[CustomConfigSnippet]:
@@ -671,7 +682,7 @@ class ClusterSupport:
     @cached_property
     def malwares(self) -> List[Malware]:
         """Get object(s) from API."""
-        return self._get_objects(Malware, ENDPOINT_MALWARES, MODEL_MALWARES)
+        return self._get_objects(Malware, ENDPOINT_PUBLIC_MALWARES, MODEL_MALWARES)
 
     @cached_property
     def crons(self) -> List[Cron]:
@@ -835,7 +846,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(
             APIUser,
-            ENDPOINT_API_USERS,
+            ENDPOINT_ADMIN_API_USERS,
         )
 
     @cached_property
@@ -911,7 +922,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_object(
             ClusterRabbitMQCredentials,
-            ENDPOINT_CLUSTERS + f"/{cluster_id}" + "/rabbitmq-credentials",
+            ENDPOINT_INTERNAL_CLUSTERS + f"/{cluster_id}" + "/rabbitmq-credentials",
         )
 
     @lru_cache(maxsize=None)
@@ -919,7 +930,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_object(
             ClusterCephFSCredentials,
-            ENDPOINT_CLUSTERS + f"/{cluster_id}" + "/cephfs-credentials",
+            ENDPOINT_INTERNAL_CLUSTERS + f"/{cluster_id}" + "/cephfs-credentials",
         )
 
     def access_logs(
@@ -967,7 +978,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(
             UNIXUsersHomeDirectoryUsage,
-            ENDPOINT_UNIX_USERS_HOME_DIRECTORIES_USAGES + f"/{cluster_id}",
+            ENDPOINT_PUBLIC_UNIX_USERS_HOME_DIRECTORIES_USAGES + f"/{cluster_id}",
             data={"timestamp": timestamp, "time_unit": time_unit.value},
         )
 
@@ -980,7 +991,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(
             UNIXUserUsage,
-            ENDPOINT_UNIX_USERS_USAGES + f"/{unix_user_id}",
+            ENDPOINT_PUBLIC_UNIX_USERS_USAGES + f"/{unix_user_id}",
             data={"timestamp": timestamp, "time_unit": time_unit.value},
         )
 
@@ -993,7 +1004,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(
             DatabaseUsage,
-            ENDPOINT_DATABASES_USAGES + f"/{database_id}",
+            ENDPOINT_PUBLIC_DATABASES_USAGES + f"/{database_id}",
             data={"timestamp": timestamp, "time_unit": time_unit.value},
         )
 
@@ -1006,7 +1017,7 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(
             MailAccountUsage,
-            ENDPOINT_MAIL_ACCOUNTS_USAGES + f"/{mail_account_id}",
+            ENDPOINT_INTERNAL_MAIL_ACCOUNTS_USAGES + f"/{mail_account_id}",
             data={"timestamp": timestamp, "time_unit": time_unit.value},
         )
 
@@ -1148,7 +1159,7 @@ class ClusterSupport:
     @cached_property
     def clusters_common_properties(self) -> dict:
         """Get clusters common properties."""
-        return self.get_data("clusters/common-properties")
+        return self.get_data(ENDPOINT_PUBLIC_CLUSTERS + "/common-properties")
 
     def get_data(self, endpoint: str, data: Optional[dict] = None) -> Any:
         """Get data from backend."""
@@ -1159,7 +1170,7 @@ class ClusterSupport:
         """Get clusters that Core API user has access to."""
         result = {}
 
-        clusters = self._execute_cluster_api_call(ENDPOINT_CLUSTERS)
+        clusters = self._execute_cluster_api_call(ENDPOINT_PUBLIC_CLUSTERS)
 
         for cluster_id in self.request.api_user_info.clusters_ids:
             cluster = next(
@@ -1190,7 +1201,7 @@ class ClusterSupport:
 
         # Execute and return
 
-        self.request.GET(f"/api/v1/{endpoint}", data)
+        self.request.GET(endpoint, data)
 
         return self.request.execute()
 
