@@ -7,7 +7,8 @@ from cyberfusion.ClusterSupport._interfaces import (
     sort_lists,
 )
 
-ENDPOINT_DATABASES_USAGES = "databases/usages"
+ENDPOINT_PUBLIC_DATABASES_USAGES = "/api/v1/databases/usages"
+ENDPOINT_INTERNAL_DATABASES_USAGES = "/internal/api/v1/databases/usages"
 
 
 class DatabaseUsage(APIObjectInterface):
@@ -23,13 +24,13 @@ class DatabaseUsage(APIObjectInterface):
         self.database_id = obj["database_id"]
         self.timestamp = obj["timestamp"]
 
-        self.datetime_object = datetime.strptime(self.timestamp, "%Y-%m-%dT%H:%M:%S.%f")
+        self.datetime_object = datetime.strptime(self.timestamp, "%Y-%m-%dT%H:%M:%S")
 
         self.database = self.support.get_databases(id_=self.database_id)[0]
 
     def create(self, *, usage: float, database_id: int) -> None:
         """Create object."""
-        url = f"/api/v1/{ENDPOINT_DATABASES_USAGES}"
+        url = ENDPOINT_INTERNAL_DATABASES_USAGES
         data = {
             "usage": usage,
             "database_id": database_id,
