@@ -8,7 +8,8 @@ from cyberfusion.ClusterSupport._interfaces import (
     sort_lists,
 )
 
-ENDPOINT_UNIX_USERS_USAGES = "unix-users/usages"
+ENDPOINT_PUBLIC_UNIX_USERS_USAGES = "/api/v1/unix-users/usages"
+ENDPOINT_INTERNAL_UNIX_USERS_USAGES = "/internal/api/v1/unix-users/usages"
 
 
 class UNIXUserUsage(APIObjectInterface):
@@ -25,7 +26,7 @@ class UNIXUserUsage(APIObjectInterface):
         self.files = obj["files"]
         self.timestamp = obj["timestamp"]
 
-        self.datetime_object = datetime.strptime(self.timestamp, "%Y-%m-%dT%H:%M:%S.%f")
+        self.datetime_object = datetime.strptime(self.timestamp, "%Y-%m-%dT%H:%M:%S")
 
         self.unix_user = self.support.get_unix_users(id_=self.unix_user_id)[0]
 
@@ -37,7 +38,7 @@ class UNIXUserUsage(APIObjectInterface):
         unix_user_id: int,
     ) -> None:
         """Create object."""
-        url = f"/api/v1/{ENDPOINT_UNIX_USERS_USAGES}"
+        url = ENDPOINT_INTERNAL_UNIX_USERS_USAGES
         data = {
             "usage": usage,
             "files": files,
